/*
 * File          : $Source: /home/erdmann/Demo/src/RCS/msg.h,v $
 * Updated       : $Author: erdmann $
 * Last Modified : $Date: 2000/11/25 19:25:53 $
 * State         : $State: Released $
 * Version       : $Revision: 1.3 $
 *
 * Copyright (C) 2000 Michael Erdmann
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program/code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US   
 *
 * Introduction
 * ============
 *
 * This package provides a simple message passing system based
 * upon the unix message queue interface.  
 *
 * The typical application at the sender looks like this:
 *
 *   Message msg;
 *
 *   msg = New_Message(4711);
 *   Add_String(msg,"Hallo");
 *   Add_Integer(msg, 2 );
 *
 *   Send_Message(0x553,  msg );
 *   Free(msg);
 *
 * On the receiver side the application will be:
 *
 *   Message msg;
 *
 *   msg = Wait_For_Message;
 *
 *
 *   switch( msg->id ) {
 *      ....
 *      case 4711:
 *         str = Get_String(msg);
 *         val = Get_Integer(msg);
 *         break;
 *      .....
 *   }
 *   free(msg);
 *
 *
 * Implementation Platform
 * =======================
 * Linux 2.2.13 / i486 unknown 
 *
 * History
 * =======
 * $Log: msg.h,v $
 * Revision 1.3  2000/11/25 19:25:53  erdmann
 * Release Version 1_1
 *
 * Revision 1.2  2000/11/25 19:23:46  erdmann
 * Release Version 1_0
 *
 * Revision 1.1  2000/11/25 14:12:27  erdmann
 * No comments
 *
 *
 */
typedef struct {
      int  id;		      // Message Number
      int  bytes_stored ;     // next insert position
      int  next_read;	      // next read position
      char buffer[ 512 ];    // this is the message buffer
   } Message_Buffer;

typedef Message_Buffer*  Message;


// Prepare a new message to be sent
Message New_Message( int );

// Add or Get an Integer from the message
Message Add_Integer( Message, int );
int Get_Integer( Message );

// Get a add a String  from/to the message
Message Add_String( Message, char*);
char *Get_String( Message );

// Wait for a message to be received on the specified message 
// queue identifier. 
Message Wait_For_Message( int );

// Send the prepared message on the specified message queue
int Send_Message( int, Message );



// ----------------
#define PUBLIC
#define PRIVATE static

